====================
django-user-payments
====================

.. image:: https://travis-ci.org/matthiask/django-user-payments.svg?branch=master
    :target: https://travis-ci.org/matthiask/django-user-payments

.. image:: https://readthedocs.org/projects/django-user-payments/badge/?version=latest
    :target: https://django-user-payments.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
